==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QFactoryInterface_shell.cpp <==
#include "QFactoryInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QFactoryInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QFactoryInterface")
    QFactoryInterface *_ptr = reinterpret_cast<QFactoryInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QFactoryInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QFactoryInterface_shell) ); }

jmethodID QFactoryInterface_shell::__shell_javaMethod(int pos) const { return QFactoryInterface_shell::__shell()->javaMethod(typeid(QFactoryInterface), pos); }

// emitting (writeShellConstructor)
QFactoryInterface_shell::QFactoryInterface_shell()
    : QFactoryInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFactoryInterface::QFactoryInterface_shell()", QFactoryInterface_shell::__shell())
    QFactoryInterface_shell::__shell()->constructed(typeid(QFactoryInterface));
}

// emitting (writeShellDestructor)
QFactoryInterface_shell::~QFactoryInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QFactoryInterface::~QFactoryInterface()", QFactoryInterface_shell::__shell())
    QFactoryInterface_shell::__shell()->destructed(typeid(QFactoryInterface));
}

void QFactoryInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QFactoryInterface_shell*>(ptr)->QFactoryInterface_shell::__shell()->tryDeleteShell(typeid(QFactoryInterface));
}

// emitting Virtual overrides (virtualFunctions)
QStringList QFactoryInterface_shell::keys() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QFactoryInterface::", QFactoryInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStringList  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QFactoryInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QFactoryInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStringList >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QFactoryInterface_shell::__shell()->warnForMethod("QFactoryInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QFactoryInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStringList();
        }
    }else{
        return QStringList();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QFactoryInterface_access::__qt_keys(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QFactoryInterface::keys() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QFactoryInterface::keys() const.";
    } else {
        QStringList __qt_return_value = keys();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QFactoryInterface_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QFactoryInterface *__qt_this = new(__qtjambi_ptr) QFactoryInterface_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QFactoryInterface_shell
void __qt_destruct_QFactoryInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QFactoryInterface")
    reinterpret_cast<QFactoryInterface_shell*>(ptr)->~QFactoryInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QFactoryInterface::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QFactoryInterface_00024Impl_initialize_1native__Lio_qt_core_QFactoryInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFactoryInterface::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFactoryInterface_0, sizeof(QFactoryInterface_shell), typeid(QFactoryInterface), true, &deleter_QFactoryInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QFactoryInterface::keys()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QFactoryInterface_00024Impl_00024ConcreteWrapper_keys_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QFactoryInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QFactoryInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFactoryInterface::keys()const", __qt_this)
        __java_return_value = static_cast<const QFactoryInterface_access*>(__qt_this)->__qt_keys(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QFactoryInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QFactoryInterface>("QFactoryInterface", "io/qt/core/QFactoryInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "keys", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QFactoryInterface, {
        ConstructorInfo(&__qt_construct_QFactoryInterface_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QFactoryInterface);
    registerSizeOfShell(typeId, sizeof(QFactoryInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QFactoryInterface* _object = dynamic_cast<QFactoryInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QFactoryInterface *object = reinterpret_cast<QFactoryInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QFactoryInterface *object = reinterpret_cast<const QFactoryInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QFactoryInterface_shell.cpp <==
#include "QFactoryInterface_shell.h"
#include <QtJambi/Cast>

void deleter_QFactoryInterface(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QFactoryInterface")
    QFactoryInterface *_ptr = reinterpret_cast<QFactoryInterface *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QFactoryInterface_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QFactoryInterface_shell) ); }

jmethodID QFactoryInterface_shell::__shell_javaMethod(int pos) const { return QFactoryInterface_shell::__shell()->javaMethod(typeid(QFactoryInterface), pos); }

// emitting (writeShellConstructor)
QFactoryInterface_shell::QFactoryInterface_shell()
    : QFactoryInterface()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFactoryInterface::QFactoryInterface_shell()", QFactoryInterface_shell::__shell())
    QFactoryInterface_shell::__shell()->constructed(typeid(QFactoryInterface));
}

// emitting (writeShellDestructor)
QFactoryInterface_shell::~QFactoryInterface_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QFactoryInterface::~QFactoryInterface()", QFactoryInterface_shell::__shell())
    QFactoryInterface_shell::__shell()->destructed(typeid(QFactoryInterface));
}

void QFactoryInterface_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QFactoryInterface_shell*>(ptr)->QFactoryInterface_shell::__shell()->tryDeleteShell(typeid(QFactoryInterface));
}

// emitting Virtual overrides (virtualFunctions)
QStringList QFactoryInterface_shell::keys() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QFactoryInterface::", QFactoryInterface_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QStringList  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QFactoryInterface_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QFactoryInterface_shell::__shell());
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QStringList >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QFactoryInterface_shell::__shell()->warnForMethod("QFactoryInterface::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QFactoryInterface::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QStringList();
        }
    }else{
        return QStringList();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QFactoryInterface_access::__qt_keys_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QFactoryInterface::keys() const." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QFactoryInterface::keys() const.";
    } else {
        QStringList __qt_return_value = keys();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QFactoryInterface()
void __qt_construct_QFactoryInterface(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFactoryInterface()")
    Q_UNUSED(__java_arguments)
    QFactoryInterface *__qt_this = new(__qtjambi_ptr) QFactoryInterface_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QFactoryInterface::QFactoryInterface()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QFactoryInterface_00024Impl_initialize_1native__Lio_qt_core_QFactoryInterface_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFactoryInterface::QFactoryInterface()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFactoryInterface, sizeof(QFactoryInterface_shell), typeid(QFactoryInterface), true, &deleter_QFactoryInterface, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QFactoryInterface_shell
void __qt_destruct_QFactoryInterface(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QFactoryInterface")
    reinterpret_cast<QFactoryInterface_shell*>(ptr)->~QFactoryInterface_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QFactoryInterface::keys()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QFactoryInterface_00024Impl_00024ConcreteWrapper_keys_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QFactoryInterface *__qt_this = QtJambiAPI::interfaceFromNativeId<QFactoryInterface>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFactoryInterface::keys()const", __qt_this)
        __java_return_value = static_cast<const QFactoryInterface_access*>(__qt_this)->__qt_keys_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QFactoryInterface(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerInterfaceTypeInfo<QFactoryInterface>("QFactoryInterface", "io/qt/core/QFactoryInterface");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "keys", "()Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QFactoryInterface, {
        ConstructorInfo(&__qt_construct_QFactoryInterface, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QFactoryInterface);
    registerSizeOfShell(typeId, sizeof(QFactoryInterface_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QFactoryInterface* _object = dynamic_cast<QFactoryInterface*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QFactoryInterface *object = reinterpret_cast<QFactoryInterface *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QFactoryInterface *object = reinterpret_cast<const QFactoryInterface *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
